.. _api_reference:

=============
API Reference
=============

Welcome to the API reference for ``aeon``.

The API reference provides a technical manual.
It describes the classes and functions included in aeon.
For a scientific manual, see the :ref:`user_guide`.

.. include:: includes/api_css.rst

.. toctree::
    :maxdepth: 1

    api_reference/base
    api_reference/forecasting
    api_reference/transformations
    api_reference/classification
    api_reference/regression
    api_reference/clustering
    api_reference/performance_metrics
    api_reference/series_as_features
    api_reference/annotation
    api_reference/datasets
    api_reference/data_format
    api_reference/deployment
    api_reference/utils
    api_reference/exceptions
